@@ -1,6 +1,6 @@
 /*
  *  Off-the-Record Messaging plugin for pidgin
- *  Copyright (C) 2004-2012  Ian Goldberg, Rob Smits,
+ *  Copyright (C) 2004-2014  Ian Goldberg, Rob Smits,
  *                           Chris Alexander, Willy Lew,
  *                           Lisa Du, Nikita Borisov
  *                           <otr@cypherpunks.ca>
@@ -56,6 +56,11 @@
 /* internationalisation header */
 #include <glib/gi18n-lib.h>
 
+#else /* ENABLE_NLS */
+
+#define _(x) (x)
+#define N_(x) (x)
+
 #endif /* ENABLE_NLS */
 
 /* libotr headers */
@@ -1156,9 +1161,10 @@ static void otrg_init_mms_table()
     static const struct s_OtrgIdProtPair {
 	char *protid;
 	int maxmsgsize;
-    } mmsPairs[8] = {{"prpl-msn", 1409}, {"prpl-icq", 2346},
+    } mmsPairs[] = {{"prpl-msn", 1409}, {"prpl-icq", 2346},
 	{"prpl-aim", 2343}, {"prpl-yahoo", 799}, {"prpl-gg", 1999},
-	{"prpl-irc", 417}, {"prpl-oscar", 2343}, {NULL, 0}};
+	{"prpl-irc", 417}, {"prpl-oscar", 2343},
+	{"prpl-novell", 1792}, {NULL, 0}};
     int i = 0;
     gchar *maxmsgsizefile;
     FILE *mmsf;
@@ -1417,7 +1423,7 @@ static PurplePluginInfo info =
 	"Ian Goldberg, Rob Smits,\n"
 	    "\t\t\tChris Alexander, Willy Lew, Lisa Du,\n"
 	    "\t\t\tNikita Borisov <otr@cypherpunks.ca>",
-	"http://otr.cypherpunks.ca/",                     /* homepage       */
+	"https://otr.cypherpunks.ca/",                    /* homepage       */
 
 	otr_plugin_load,                                  /* load           */
 	otr_plugin_unload,                                /* unload         */
